public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "PierreGondois" <pierre.gondois@arm.com>
To: devel@edk2.groups.io
Cc: Pierre Gondois <pierre.gondois@arm.com>,
	Sami Mujawar <sami.mujawar@arm.com>,
	Pierre Gondois <Pierre.Gondois@arm.com>,
	Yeo Reum Yun <YeoReum.Yun@arm.com>,
	Sunil V L <sunilvl@ventanamicro.com>,
	AbdulLateef Attar <AbdulLateef.Attar@amd.com>,
	Jeshua Smith <jeshuas@nvidia.com>,
	Jeff Brasen <jbrasen@nvidia.com>,
	Girish Mahadevan <gmahadevan@nvidia.com>,
	Leif Lindholm <quic_llindhol@quicinc.com>,
	Meenakshi Aggarwal <meenakshi.aggarwal@nxp.com>
Subject: [edk2-devel] [PATCH 06/19] DynamicTablesPkg: Move PCI device Handle object to Arch Common
Date: Thu, 21 Mar 2024 16:59:11 +0100	[thread overview]
Message-ID: <20240321155924.707272-7-pierre.gondois@arm.com> (raw)
In-Reply-To: <20240321155924.707272-1-pierre.gondois@arm.com>

From: Sami Mujawar <sami.mujawar@arm.com>

Move the PCI device Handle object from Arm Namespace to the
Arch Common namespace.

Correspondingly also update the following modules to reflect the
changes introduced by the move:
 - SRAT generator
 - ConfigurationManagerObjectParser
 - Dynamic Plat Repo TokenFixer map.

Cc: Pierre Gondois <Pierre.Gondois@arm.com>
Cc: Yeo Reum Yun <YeoReum.Yun@arm.com>
Cc: AbdulLateef Attar <AbdulLateef.Attar@amd.com>
Cc: Jeshua Smith <jeshuas@nvidia.com>
Cc: Jeff Brasen <jbrasen@nvidia.com>
Cc: Girish Mahadevan <gmahadevan@nvidia.com>
Cc: Leif Lindholm <quic_llindhol@quicinc.com>
Cc: Meenakshi Aggarwal <meenakshi.aggarwal@nxp.com>
Signed-off-by: Sami Mujawar <sami.mujawar@arm.com>
Signed-off-by: Pierre Gondois <pierre.gondois@arm.com>
---
 .../Include/ArchCommonNameSpaceObjects.h      | 20 ++++++++
 .../Include/ArmNameSpaceObjects.h             | 48 ++++++-------------
 .../Acpi/Arm/AcpiSratLibArm/SratGenerator.c   | 14 +++---
 .../DynamicPlatRepoLib/CmObjectTokenFixer.c   | 27 +++++------
 .../ConfigurationManagerObjectParser.c        |  6 +--
 DynamicTablesPkg/Readme.md                    | 30 ++++++------
 6 files changed, 72 insertions(+), 73 deletions(-)

diff --git a/DynamicTablesPkg/Include/ArchCommonNameSpaceObjects.h b/DynamicTablesPkg/Include/ArchCommonNameSpaceObjects.h
index 0b450e8f99c2..230d0bc334c0 100644
--- a/DynamicTablesPkg/Include/ArchCommonNameSpaceObjects.h
+++ b/DynamicTablesPkg/Include/ArchCommonNameSpaceObjects.h
@@ -33,6 +33,7 @@ typedef enum ArchCommonObjectID {
   EArchCommonObjPciInterruptMapInfo,            ///< 10 - Pci Interrupt Map Info
   EArchCommonObjMemoryAffinityInfo,             ///< 11 - Memory Affinity Info
   EArchCommonObjDeviceHandleAcpi,               ///< 12 - Device Handle Acpi
+  EArchCommonObjDeviceHandlePci,                ///< 13 - Device Handle Pci
   EArchCommonObjMax
 } EARCH_COMMON_OBJECT_ID;
 
@@ -256,6 +257,25 @@ typedef struct CmArchCommonDeviceHandleAcpi {
   UINT32    Uid;
 } CM_ARCH_COMMON_DEVICE_HANDLE_ACPI;
 
+/** A structure that describes the PCI Device Handle (Type 1) in the
+    Generic Initiator Affinity structure in SRAT
+
+    ID: EArchCommonObjDeviceHandlePci
+*/
+typedef struct CmArchCommonDeviceHandlePci {
+  /// PCI Segment Number
+  UINT16    SegmentNumber;
+
+  /// PCI Bus Number - Max 256 busses (Bits 15:8 of BDF)
+  UINT8     BusNumber;
+
+  /// PCI Device Number - Max 32 devices (Bits 7:3 of BDF)
+  UINT8     DeviceNumber;
+
+  /// PCI Function Number - Max 8 functions (Bits 2:0 of BDF)
+  UINT8     FunctionNumber;
+} CM_ARCH_COMMON_DEVICE_HANDLE_PCI;
+
 #pragma pack()
 
 #endif // ARCH_COMMON_NAMESPACE_OBJECTS_H_
diff --git a/DynamicTablesPkg/Include/ArmNameSpaceObjects.h b/DynamicTablesPkg/Include/ArmNameSpaceObjects.h
index 64c5f2677246..05691e6fcf69 100644
--- a/DynamicTablesPkg/Include/ArmNameSpaceObjects.h
+++ b/DynamicTablesPkg/Include/ArmNameSpaceObjects.h
@@ -50,21 +50,20 @@ typedef enum ArmObjectID {
   EArmObjSmmuInterruptArray,                                   ///< 19 - SMMU Interrupt Array
   EArmObjProcHierarchyInfo,                                    ///< 20 - Processor Hierarchy Info
   EArmObjCacheInfo,                                            ///< 21 - Cache Info
-  EArmObjDeviceHandlePci,                                      ///< 22 - Device Handle Pci
-  EArmObjGenericInitiatorAffinityInfo,                         ///< 23 - Generic Initiator Affinity
-  EArmObjCmn600Info,                                           ///< 24 - CMN-600 Info
-  EArmObjLpiInfo,                                              ///< 25 - Lpi Info
-  EArmObjRmr,                                                  ///< 26 - Reserved Memory Range Node
-  EArmObjMemoryRangeDescriptor,                                ///< 27 - Memory Range Descriptor
-  EArmObjCpcInfo,                                              ///< 28 - Continuous Performance Control Info
-  EArmObjPccSubspaceType0Info,                                 ///< 29 - Pcc Subspace Type 0 Info
-  EArmObjPccSubspaceType1Info,                                 ///< 30 - Pcc Subspace Type 2 Info
-  EArmObjPccSubspaceType2Info,                                 ///< 31 - Pcc Subspace Type 2 Info
-  EArmObjPccSubspaceType3Info,                                 ///< 32 - Pcc Subspace Type 3 Info
-  EArmObjPccSubspaceType4Info,                                 ///< 33 - Pcc Subspace Type 4 Info
-  EArmObjPccSubspaceType5Info,                                 ///< 34 - Pcc Subspace Type 5 Info
-  EArmObjEtInfo,                                               ///< 35 - Embedded Trace Extension/Module Info
-  EArmObjPsdInfo,                                              ///< 36 - P-State Dependency (PSD) Info
+  EArmObjGenericInitiatorAffinityInfo,                         ///< 22 - Generic Initiator Affinity
+  EArmObjCmn600Info,                                           ///< 23 - CMN-600 Info
+  EArmObjLpiInfo,                                              ///< 24 - Lpi Info
+  EArmObjRmr,                                                  ///< 25 - Reserved Memory Range Node
+  EArmObjMemoryRangeDescriptor,                                ///< 26 - Memory Range Descriptor
+  EArmObjCpcInfo,                                              ///< 27 - Continuous Performance Control Info
+  EArmObjPccSubspaceType0Info,                                 ///< 28 - Pcc Subspace Type 0 Info
+  EArmObjPccSubspaceType1Info,                                 ///< 29 - Pcc Subspace Type 2 Info
+  EArmObjPccSubspaceType2Info,                                 ///< 30 - Pcc Subspace Type 2 Info
+  EArmObjPccSubspaceType3Info,                                 ///< 31 - Pcc Subspace Type 3 Info
+  EArmObjPccSubspaceType4Info,                                 ///< 32 - Pcc Subspace Type 4 Info
+  EArmObjPccSubspaceType5Info,                                 ///< 33 - Pcc Subspace Type 5 Info
+  EArmObjEtInfo,                                               ///< 34 - Embedded Trace Extension/Module Info
+  EArmObjPsdInfo,                                              ///< 35 - P-State Dependency (PSD) Info
   EArmObjMax
 } EARM_OBJECT_ID;
 
@@ -719,25 +718,6 @@ typedef struct CmArmCacheInfo {
   UINT32             CacheId;
 } CM_ARM_CACHE_INFO;
 
-/** A structure that describes the PCI Device Handle (Type 1) in the
-    Generic Initiator Affinity structure in SRAT
-
-    ID: EArmObjDeviceHandlePci
-*/
-typedef struct CmArmDeviceHandlePci {
-  /// PCI Segment Number
-  UINT16    SegmentNumber;
-
-  /// PCI Bus Number - Max 256 busses (Bits 15:8 of BDF)
-  UINT8     BusNumber;
-
-  /// PCI Device Number - Max 32 devices (Bits 7:3 of BDF)
-  UINT8     DeviceNumber;
-
-  /// PCI Function Number - Max 8 functions (Bits 2:0 of BDF)
-  UINT8     FunctionNumber;
-} CM_ARM_DEVICE_HANDLE_PCI;
-
 /** A structure that describes the Generic Initiator Affinity structure in SRAT
 
     ID: EArmObjGenericInitiatorAffinityInfo
diff --git a/DynamicTablesPkg/Library/Acpi/Arm/AcpiSratLibArm/SratGenerator.c b/DynamicTablesPkg/Library/Acpi/Arm/AcpiSratLibArm/SratGenerator.c
index c65a28cd142a..66fefc80f5f6 100644
--- a/DynamicTablesPkg/Library/Acpi/Arm/AcpiSratLibArm/SratGenerator.c
+++ b/DynamicTablesPkg/Library/Acpi/Arm/AcpiSratLibArm/SratGenerator.c
@@ -35,7 +35,7 @@
     - EArchCommonObjMemoryAffinityInfo (OPTIONAL)
     - EArmObjGenericInitiatorAffinityInfo (OPTIONAL)
     - EArchCommonObjDeviceHandleAcpi (OPTIONAL)
-    - EArmObjDeviceHandlePci (OPTIONAL)
+    - EArchCommonObjDeviceHandlePci (OPTIONAL)
 */
 
 /** This macro expands to a function that retrieves the GIC
@@ -92,9 +92,9 @@ GET_OBJECT_LIST (
   information from the Configuration Manager.
 */
 GET_OBJECT_LIST (
-  EObjNameSpaceArm,
-  EArmObjDeviceHandlePci,
-  CM_ARM_DEVICE_HANDLE_PCI
+  EObjNameSpaceArchCommon,
+  EArchCommonObjDeviceHandlePci,
+  CM_ARCH_COMMON_DEVICE_HANDLE_PCI
   );
 
 /** Return the PCI Device information in BDF format
@@ -110,7 +110,7 @@ GET_OBJECT_LIST (
 STATIC
 UINT16
 GetBdf (
-  IN CONST CM_ARM_DEVICE_HANDLE_PCI  *DeviceHandlePci
+  IN CONST CM_ARCH_COMMON_DEVICE_HANDLE_PCI  *DeviceHandlePci
   )
 {
   UINT16  Bdf;
@@ -302,7 +302,7 @@ AddGenericInitiatorAffinity (
   EFI_STATUS                                         Status;
   EFI_ACPI_6_3_GENERIC_INITIATOR_AFFINITY_STRUCTURE  *GenInitAff;
   CM_ARCH_COMMON_DEVICE_HANDLE_ACPI                  *DeviceHandleAcpi;
-  CM_ARM_DEVICE_HANDLE_PCI                           *DeviceHandlePci;
+  CM_ARCH_COMMON_DEVICE_HANDLE_PCI                   *DeviceHandlePci;
   UINT32                                             DeviceHandleCount;
 
   ASSERT (Srat != NULL);
@@ -362,7 +362,7 @@ AddGenericInitiatorAffinity (
     } else if (GenInitAffInfo->DeviceHandleType ==
                EFI_ACPI_6_3_PCI_DEVICE_HANDLE)
     {
-      Status = GetEArmObjDeviceHandlePci (
+      Status = GetEArchCommonObjDeviceHandlePci (
                  CfgMgrProtocol,
                  GenInitAffInfo->DeviceHandleToken,
                  &DeviceHandlePci,
diff --git a/DynamicTablesPkg/Library/Common/DynamicPlatRepoLib/CmObjectTokenFixer.c b/DynamicTablesPkg/Library/Common/DynamicPlatRepoLib/CmObjectTokenFixer.c
index 43aae423814f..d5ee9317e693 100644
--- a/DynamicTablesPkg/Library/Common/DynamicPlatRepoLib/CmObjectTokenFixer.c
+++ b/DynamicTablesPkg/Library/Common/DynamicPlatRepoLib/CmObjectTokenFixer.c
@@ -165,21 +165,20 @@ CM_OBJECT_TOKEN_FIXER  TokenFixer[EArmObjMax] = {
   NULL,                             ///< 19 - SMMU Interrupt Array
   TokenFixerNotImplemented,         ///< 20 - Processor Hierarchy Info
   TokenFixerNotImplemented,         ///< 21 - Cache Info
-  NULL,                             ///< 22 - Device Handle Pci
-  NULL,                             ///< 23 - Generic Initiator Affinity
-  NULL,                             ///< 24 - CMN-600 Info
-  NULL,                             ///< 25 - Lpi Info
-  NULL,                             ///< 26 - Reserved Memory Range Node
-  NULL,                             ///< 27 - Memory Range Descriptor
-  NULL,                             ///< 28 - Continuous Performance Control Info
-  NULL,                             ///< 29 - Pcc Subspace Type 0 Info
+  NULL,                             ///< 22 - Generic Initiator Affinity
+  NULL,                             ///< 23 - CMN-600 Info
+  NULL,                             ///< 24 - Lpi Info
+  NULL,                             ///< 25 - Reserved Memory Range Node
+  NULL,                             ///< 26 - Memory Range Descriptor
+  NULL,                             ///< 27 - Continuous Performance Control Info
+  NULL,                             ///< 28 - Pcc Subspace Type 0 Info
+  NULL,                             ///< 29 - Pcc Subspace Type 2 Info
   NULL,                             ///< 30 - Pcc Subspace Type 2 Info
-  NULL,                             ///< 31 - Pcc Subspace Type 2 Info
-  NULL,                             ///< 32 - Pcc Subspace Type 3 Info
-  NULL,                             ///< 33 - Pcc Subspace Type 4 Info
-  NULL,                             ///< 34 - Pcc Subspace Type 5 Info
-  NULL,                             ///< 35 - Embedded Trace Extension/Module Info
-  NULL                              ///< 36 - P-State Dependency (PSD) Info
+  NULL,                             ///< 31 - Pcc Subspace Type 3 Info
+  NULL,                             ///< 32 - Pcc Subspace Type 4 Info
+  NULL,                             ///< 33 - Pcc Subspace Type 5 Info
+  NULL,                             ///< 34 - Embedded Trace Extension/Module Info
+  NULL                              ///< 35 - P-State Dependency (PSD) Info
 };
 
 /** CmObj token fixer.
diff --git a/DynamicTablesPkg/Readme.md b/DynamicTablesPkg/Readme.md
index f82c37f4afeb..9c7738983df5 100644
--- a/DynamicTablesPkg/Readme.md
+++ b/DynamicTablesPkg/Readme.md
@@ -462,21 +462,20 @@ The CM_OBJECT_ID type is used to identify the Configuration Manager
 |  19   | SMMU Interrupt Array                      | |
 |  20   | Processor Hierarchy Info                  | Move to Arch Common NS |
 |  21   | Cache Info                                | Move to Arch Common NS |
-|  22   | Device Handle PCI                         | Move to Arch Common NS |
-|  23   | Generic Initiator Affinity Info           | Move to Arch Common NS |
-|  24   | CMN 600 Info                              | |
-|  25   | Low Power Idle State Info                 | Move to Arch Common NS |
-|  26   | Reserved Memory Range Node                | |
-|  27   | Memory Range Descriptor                   | |
-|  28   | Continuous Performance Control Info       | Move to Arch Common NS |
-|  29   | Pcc Subspace Type 0 Info                  | Move to Arch Common NS |
-|  30   | Pcc Subspace Type 1 Info                  | Move to Arch Common NS |
-|  31   | Pcc Subspace Type 2 Info                  | Move to Arch Common NS |
-|  32   | Pcc Subspace Type 3 Info                  | Move to Arch Common NS |
-|  33   | Pcc Subspace Type 4 Info                  | Move to Arch Common NS |
-|  34   | Pcc Subspace Type 5 Info                  | Move to Arch Common NS |
-|  35   | Embedded Trace Extension/Module Info      | |
-|  36   | P-State Dependency (PSD) Info             | Move to Arch Common NS |
+|  22   | Generic Initiator Affinity Info           | Move to Arch Common NS |
+|  23   | CMN 600 Info                              | |
+|  24   | Low Power Idle State Info                 | Move to Arch Common NS |
+|  25   | Reserved Memory Range Node                | |
+|  26   | Memory Range Descriptor                   | |
+|  27   | Continuous Performance Control Info       | Move to Arch Common NS |
+|  28   | Pcc Subspace Type 0 Info                  | Move to Arch Common NS |
+|  29   | Pcc Subspace Type 1 Info                  | Move to Arch Common NS |
+|  30   | Pcc Subspace Type 2 Info                  | Move to Arch Common NS |
+|  31   | Pcc Subspace Type 3 Info                  | Move to Arch Common NS |
+|  32   | Pcc Subspace Type 4 Info                  | Move to Arch Common NS |
+|  33   | Pcc Subspace Type 5 Info                  | Move to Arch Common NS |
+|  34   | Embedded Trace Extension/Module Info      | |
+|  35   | P-State Dependency (PSD) Info             | Move to Arch Common NS |
 |  `*`  | All other values are reserved.            | |
 
 #### Object ID's in the Arch Common Namespace:
@@ -496,4 +495,5 @@ The CM_OBJECT_ID type is used to identify the Configuration Manager
 |  10   | PCI Interrupt Map Info            | |
 |  11   | Memory Affinity Info              | |
 |  12   | Device Handle Acpi                | |
+|  13   | Device Handle PCI                 | |
 |  `*`  | All other values are reserved.    | |
diff --git a/DynamicTablesPkg/Library/Common/TableHelperLib/ConfigurationManagerObjectParser.c b/DynamicTablesPkg/Library/Common/TableHelperLib/ConfigurationManagerObjectParser.c
index 9326ea639351..4b4965dfb00f 100644
--- a/DynamicTablesPkg/Library/Common/TableHelperLib/ConfigurationManagerObjectParser.c
+++ b/DynamicTablesPkg/Library/Common/TableHelperLib/ConfigurationManagerObjectParser.c
@@ -372,9 +372,9 @@ STATIC CONST CM_OBJ_PARSER  CmArchCommonDeviceHandleAcpiParser[] = {
   { "Uid", 4, "0x%x",   NULL }
 };
 
 /** A parser for EArmObjDeviceHandlePci.
 */
-STATIC CONST CM_OBJ_PARSER  CmArmDeviceHandlePciParser[] = {
+STATIC CONST CM_OBJ_PARSER  CmArchCommonDeviceHandlePciParser[] = {
   { "SegmentNumber",  2, "0x%x", NULL },
   { "BusNumber",      1, "0x%x", NULL },
   { "DeviceNumber",   1, "0x%x", NULL },
@@ -683,6 +683,7 @@ STATIC CONST CM_OBJ_PARSER_ARRAY  ArchCommonNamespaceObjectParser[] = {
   CM_PARSER_ADD_OBJECT (EArchCommonObjPciInterruptMapInfo,       CmArchCommonPciInterruptMapInfoParser),
   CM_PARSER_ADD_OBJECT (EArchCommonObjMemoryAffinityInfo,        CmArchCommonMemoryAffinityInfoParser),
   CM_PARSER_ADD_OBJECT (EArchCommonObjDeviceHandleAcpi,          CmArchCommonDeviceHandleAcpiParser),
+  CM_PARSER_ADD_OBJECT (EArchCommonObjDeviceHandlePci,           CmArchCommonDeviceHandlePciParser),
   CM_PARSER_ADD_OBJECT_RESERVED (EArchCommonObjMax)
 };
 
@@ -711,7 +712,6 @@ STATIC CONST CM_OBJ_PARSER_ARRAY  ArmNamespaceObjectParser[] = {
   CM_PARSER_ADD_OBJECT (EArmObjSmmuInterruptArray,          CmArchCommonGenericInterruptParser),
   CM_PARSER_ADD_OBJECT (EArmObjProcHierarchyInfo,           CmArmProcHierarchyInfoParser),
   CM_PARSER_ADD_OBJECT (EArmObjCacheInfo,                   CmArmCacheInfoParser),
-  CM_PARSER_ADD_OBJECT (EArmObjDeviceHandlePci,             CmArmDeviceHandlePciParser),
   CM_PARSER_ADD_OBJECT (EArmObjGenericInitiatorAffinityInfo,CmArmGenericInitiatorAffinityInfoParser),
   CM_PARSER_ADD_OBJECT (EArmObjCmn600Info,                  CmArmCmn600InfoParser),
   CM_PARSER_ADD_OBJECT (EArmObjLpiInfo,                     CmArmLpiInfoParser),
@@ -372,9 +372,9 @@ STATIC CONST CM_OBJ_PARSER  CmArchCommonDeviceHandleAcpiParser[] = {
 };
 
-/** A parser for EArmObjDeviceHandlePci.
+/** A parser for EArchCommonObjDeviceHandlePci.
 */
-- 
2.25.1



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#116984): https://edk2.groups.io/g/devel/message/116984
Mute This Topic: https://groups.io/mt/105068154/7686176
Group Owner: devel+owner@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [rebecca@openfw.io]
-=-=-=-=-=-=-=-=-=-=-=-



  parent reply	other threads:[~2024-03-21 16:00 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-03-21 15:59 [edk2-devel] [PATCH 00/19] DynamicTablesPkg: Move objects to Arch Common NameSpace (second) PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 01/19] DynamicTablesPkg: Move Pci Address Map Info to Arch Common PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 02/19] DynamicTablesPkg: Move CM_ARM_GENERIC_INTERRUPT struct " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 03/19] DynamicTablesPkg: Move Pci Interrupt Map Info " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 04/19] DynamicTablesPkg: Move Mem Affinity " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 05/19] DynamicTablesPkg: Move ACPI device Handle object " PierreGondois
2024-03-21 15:59 ` PierreGondois [this message]
2024-03-21 15:59 ` [edk2-devel] [PATCH 07/19] DynamicTablesPkg: Move Generic Initiator affinity info " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 08/19] DynamicTablesPkg: Move LPI info object " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 09/19] DynamicTablesPkg: Rename GicCToken field in Processor Hierarchy Info PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 10/19] DynamicTablesPkg: Move Processor hierarchy info to Arch Common PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 11/19] DynamicTablesPkg: Move Cache " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 12/19] DynamicTablesPkg: Move Continuous perf control " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 13/19] DynamicTablesPkg: Move PCC structure definitions " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 14/19] DynamicTablesPkg: Move PCC Type0 info " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 15/19] DynamicTablesPkg: Move PCC Type1 " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 16/19] DynamicTablesPkg: Move PCC Type2 " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 17/19] DynamicTablesPkg: Move PCC Type 3 & 4 " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 18/19] DynamicTablesPkg: Move PCC Type 5 " PierreGondois
2024-03-21 15:59 ` [edk2-devel] [PATCH 19/19] DynamicTablesPkg: Move PSD " PierreGondois

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240321155924.707272-7-pierre.gondois@arm.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox